/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2019 TIBCO Software Inc. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */

import com.aspose.imaging.jasperreports.export.bmp.ASBmpExporter;
import com.aspose.imaging.jasperreports.export.config.ASExportInputImpl;
import com.aspose.imaging.jasperreports.export.config.ASExporterOutputImpl;
import com.aspose.imaging.jasperreports.export.dcm.ASDicomExporter;
import com.aspose.imaging.jasperreports.export.emf.ASEmfExporter;
import com.aspose.imaging.jasperreports.export.gif.ASGifExporter;
import com.aspose.imaging.jasperreports.export.html.ASHtml5CanvasExporter;
import com.aspose.imaging.jasperreports.export.jpg.ASJpegExporter;
import com.aspose.imaging.jasperreports.export.jpg2000.ASJpeg2000Exporter;
import com.aspose.imaging.jasperreports.export.pdf.ASPdfExporter;
import com.aspose.imaging.jasperreports.export.png.ASPngExporter;
import com.aspose.imaging.jasperreports.export.psd.ASPsdExporter;
import com.aspose.imaging.jasperreports.export.svg.ASSvgExporter;
import com.aspose.imaging.jasperreports.export.tiff.ASTiffExporter;
import com.aspose.imaging.jasperreports.export.webp.ASWebPExporter;
import com.aspose.imaging.jasperreports.export.wmf.ASWmfExporter;
import net.sf.jasperreports.engine.JRException;
import net.sf.jasperreports.engine.JasperFillManager;
import net.sf.jasperreports.engine.util.AbstractSampleApp;

import java.io.File;
import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;


/**
 * @author Teodor Danciu (teodord@users.sourceforge.net)
 */
public class ChartsApp extends AbstractSampleApp {


    /**
     *
     */
    public static void main(String[] args) {
        main(new ChartsApp(), args);
    }


    @Override
    public void test() throws JRException {
        fill();
		pdf();
		bmp();
		gif();
		jpeg();
		png();
		tiff();
		psd();
		jpeg2000();
		webp();
		emf();
		dicom();
		svg();
		wmf();
		html5Canvas();
    }


    /**
     *
     */
    public void fill() throws JRException {
        Map<String, Object> parameters = new HashMap<String, Object>();
        parameters.put("MaxOrderID", 12500);

        File[] files = getFiles(new File("build/reports"), "jasper");
        for (int i = 0; i < files.length; i++) {
            File reportFile = files[i];
            long start = System.currentTimeMillis();
            JasperFillManager.fillReportToFile(
                    reportFile.getAbsolutePath(),
                    new HashMap<String, Object>(parameters),
                    getDemoHsqldbConnection()
            );
            System.err.println("Report : " + reportFile + ". Filling time : " + (System.currentTimeMillis() - start));
        }
    }

    public void html5Canvas() throws JRException {
        File[] files = getFiles(new File("build/reports"), "jrprint");
        for (int i = 0; i < files.length; i++) {
            File reportFile = files[i];
            long start = System.currentTimeMillis();
            ASHtml5CanvasExporter exporter = new ASHtml5CanvasExporter();
            exporter.setExporterInput(new ASExportInputImpl(reportFile));
			String reportFileName = reportFile.getName();
			exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/" + reportFileName.substring(0, reportFileName.length() -8) + ".html"));
            exporter.exportReport();
            System.err.println("Report : " + reportFile + ". HTML5 canvas creation time : " + (System.currentTimeMillis() - start));
        }
    }

    public void wmf() throws JRException {
        File[] files = getFiles(new File("build/reports"), "jrprint");
        for (int i = 0; i < files.length; i++) {
            File reportFile = files[i];
            long start = System.currentTimeMillis();
            ASWmfExporter exporter = new ASWmfExporter();
            exporter.setExporterInput(new ASExportInputImpl(reportFile));
			String reportFileName = reportFile.getName();
			exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/" + reportFileName.substring(0, reportFileName.length() - 8) + ".wmf"));
            exporter.exportReport();
            System.err.println("Report : " + reportFile + ". WMF creation time : " + (System.currentTimeMillis() - start));
        }
    }

    public void svg() throws JRException {
        File[] files = getFiles(new File("build/reports"), "jrprint");
        for (int i = 0; i < files.length; i++) {
            File reportFile = files[i];
            long start = System.currentTimeMillis();
            ASSvgExporter exporter = new ASSvgExporter();
            exporter.setExporterInput(new ASExportInputImpl(reportFile));
			String reportFileName = reportFile.getName();
			exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/" + reportFileName.substring(0, reportFileName.length() - 8) + ".svg"));
            exporter.exportReport();
            System.err.println("Report : " + reportFile + ". SVG creation time : " + (System.currentTimeMillis() - start));
        }
    }

    public void dicom() throws JRException {
        File[] files = getFiles(new File("build/reports"), "jrprint");
        for (int i = 0; i < files.length; i++) {
            File reportFile = files[i];
            long start = System.currentTimeMillis();
            ASDicomExporter exporter = new ASDicomExporter();
            exporter.setExporterInput(new ASExportInputImpl(reportFile));
			String reportFileName = reportFile.getName();
			exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/" + reportFileName.substring(0, reportFileName.length() - 8) + ".dcm"));
            exporter.exportReport();
            System.err.println("Report : " + reportFile + ". DICOM creation time : " + (System.currentTimeMillis() - start));
        }
    }

    public void emf() throws JRException {
        File[] files = getFiles(new File("build/reports"), "jrprint");
        for (int i = 0; i < files.length; i++) {
            File reportFile = files[i];
            long start = System.currentTimeMillis();
            ASEmfExporter exporter = new ASEmfExporter();
            exporter.setExporterInput(new ASExportInputImpl(reportFile));
			String reportFileName = reportFile.getName();
			exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/" + reportFileName.substring(0, reportFileName.length() - 8) + ".emf"));
            exporter.exportReport();
            System.err.println("Report : " + reportFile + ". EMF creation time : " + (System.currentTimeMillis() - start));
        }
    }

    public void webp() throws JRException {
        File[] files = getFiles(new File("build/reports"), "jrprint");
        for (int i = 0; i < files.length; i++) {
            File reportFile = files[i];
            long start = System.currentTimeMillis();
            ASWebPExporter exporter = new ASWebPExporter();
            exporter.setExporterInput(new ASExportInputImpl(reportFile));
			String reportFileName = reportFile.getName();
			exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/" + reportFileName.substring(0, reportFileName.length() -8) + ".webp"));
            exporter.exportReport();
            System.err.println("Report : " + reportFile + ". WEBP creation time : " + (System.currentTimeMillis() - start));
        }
    }

    public void jpeg2000() throws JRException {
        File[] files = getFiles(new File("build/reports"), "jrprint");
        for (int i = 0; i < files.length; i++) {
            File reportFile = files[i];
            long start = System.currentTimeMillis();
            ASJpeg2000Exporter exporter = new ASJpeg2000Exporter();
            exporter.setExporterInput(new ASExportInputImpl(reportFile));
			String reportFileName = reportFile.getName();
			exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/" + reportFileName.substring(0, reportFileName.length() - 8) + ".jp2"));
            exporter.exportReport();
            System.err.println("Report : " + reportFile + ". JPEG2000 creation time : " + (System.currentTimeMillis() - start));
        }
    }

    public void psd() throws JRException {
        File[] files = getFiles(new File("build/reports"), "jrprint");
        for (int i = 0; i < files.length; i++) {
            File reportFile = files[i];
            long start = System.currentTimeMillis();
            ASPsdExporter exporter = new ASPsdExporter();
            exporter.setExporterInput(new ASExportInputImpl(reportFile));
			String reportFileName = reportFile.getName();
			exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/" + reportFileName.substring(0, reportFileName.length() - 8) + ".psd"));
            exporter.exportReport();
            System.err.println("Report : " + reportFile + ". PSD creation time : " + (System.currentTimeMillis() - start));
        }
    }

    public void tiff() throws JRException {
        File[] files = getFiles(new File("build/reports"), "jrprint");
        for (int i = 0; i < files.length; i++) {
            File reportFile = files[i];
            long start = System.currentTimeMillis();
            ASTiffExporter exporter = new ASTiffExporter();
            exporter.setExporterInput(new ASExportInputImpl(reportFile));
			String reportFileName = reportFile.getName();
			exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/" + reportFileName.substring(0, reportFileName.length() -8) + ".tiff"));
            exporter.exportReport();
            System.err.println("Report : " + reportFile + ". TIFF creation time : " + (System.currentTimeMillis() - start));
        }
    }

    public void png() throws JRException {
        File[] files = getFiles(new File("build/reports"), "jrprint");
        for (int i = 0; i < files.length; i++) {
            File reportFile = files[i];
            long start = System.currentTimeMillis();
            ASPngExporter exporter = new ASPngExporter();
            exporter.setExporterInput(new ASExportInputImpl(reportFile));
			String reportFileName = reportFile.getName();
			exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/" + reportFileName.substring(0, reportFileName.length() - 8) + ".png"));
            exporter.exportReport();
            System.err.println("Report : " + reportFile + ". PNG creation time : " + (System.currentTimeMillis() - start));
        }
    }

    public void jpeg() throws JRException {
        File[] files = getFiles(new File("build/reports"), "jrprint");
        for (int i = 0; i < files.length; i++) {
            File reportFile = files[i];
            long start = System.currentTimeMillis();
            ASJpegExporter exporter = new ASJpegExporter();
            exporter.setExporterInput(new ASExportInputImpl(reportFile));
			String reportFileName = reportFile.getName();
			exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/" + reportFileName.substring(0, reportFileName.length() -8) + ".jpg"));
            exporter.exportReport();
            System.err.println("Report : " + reportFile + ". JPEG creation time : " + (System.currentTimeMillis() - start));
        }
    }

    public void gif() throws JRException {
        File[] files = getFiles(new File("build/reports"), "jrprint");
        for (int i = 0; i < files.length; i++) {
            File reportFile = files[i];
            long start = System.currentTimeMillis();
            ASGifExporter exporter = new ASGifExporter();
            exporter.setExporterInput(new ASExportInputImpl(reportFile));
			String reportFileName = reportFile.getName();
			exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/" + reportFileName.substring(0, reportFileName.length() - 8) + ".gif"));
            exporter.exportReport();
            System.err.println("Report : " + reportFile + ". GIF creation time : " + (System.currentTimeMillis() - start));
        }
    }

    public void bmp() throws JRException {
        File[] files = getFiles(new File("build/reports"), "jrprint");
        for (int i = 0; i < files.length; i++) {
            File reportFile = files[i];
            long start = System.currentTimeMillis();
            ASBmpExporter exporter = new ASBmpExporter();
            exporter.setExporterInput(new ASExportInputImpl(reportFile));
			String reportFileName = reportFile.getName();
			exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/" + reportFileName.substring(0, reportFileName.length() - 8) + ".bmp"));
            exporter.exportReport();
            System.err.println("Report : " + reportFile + ". BMP creation time : " + (System.currentTimeMillis() - start));
        }
    }


    /**
     *
     */
    public void pdf() throws JRException {
        File[] files = getFiles(new File("build/reports"), "jrprint");
        for (int i = 0; i < files.length; i++) {
            File reportFile = files[i];
            long start = System.currentTimeMillis();
            ASPdfExporter exporter = new ASPdfExporter();
            exporter.setExporterInput(new ASExportInputImpl(reportFile));
			String reportFileName = reportFile.getName();
			exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/" + reportFileName.substring(0, reportFileName.length() - 8) + ".pdf"));
            exporter.exportReport();
            System.err.println("Report : " + reportFile + ". PDF creation time : " + (System.currentTimeMillis() - start));
        }
    }


    /**
     *
     */
    public static final Date truncateToMonth(Date date) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        int year = calendar.get(Calendar.YEAR);
        int month = calendar.get(Calendar.MONTH);
        calendar.clear();
        calendar.set(Calendar.YEAR, year);
        calendar.set(Calendar.MONTH, month);
        return calendar.getTime();
    }

}
