/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2019 TIBCO Software Inc. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */

import com.aspose.imaging.jasperreports.export.bmp.ASBmpExporter;
import com.aspose.imaging.jasperreports.export.config.ASExportInputImpl;
import com.aspose.imaging.jasperreports.export.config.ASExporterOutputImpl;
import com.aspose.imaging.jasperreports.export.dcm.ASDicomExporter;
import com.aspose.imaging.jasperreports.export.emf.ASEmfExporter;
import com.aspose.imaging.jasperreports.export.gif.ASGifExporter;
import com.aspose.imaging.jasperreports.export.html.ASHtml5CanvasExporter;
import com.aspose.imaging.jasperreports.export.jpg.ASJpegExporter;
import com.aspose.imaging.jasperreports.export.jpg2000.ASJpeg2000Exporter;
import com.aspose.imaging.jasperreports.export.pdf.ASPdfExporter;
import com.aspose.imaging.jasperreports.export.png.ASPngExporter;
import com.aspose.imaging.jasperreports.export.psd.ASPsdExporter;
import com.aspose.imaging.jasperreports.export.svg.ASSvgExporter;
import com.aspose.imaging.jasperreports.export.tiff.ASTiffExporter;
import com.aspose.imaging.jasperreports.export.webp.ASWebPExporter;
import com.aspose.imaging.jasperreports.export.wmf.ASWmfExporter;
import net.sf.jasperreports.engine.JRException;
import net.sf.jasperreports.engine.JasperFillManager;
import net.sf.jasperreports.engine.JasperPrintManager;
import net.sf.jasperreports.engine.JasperReport;
import net.sf.jasperreports.engine.util.AbstractSampleApp;
import net.sf.jasperreports.engine.util.JRLoader;

import java.util.HashMap;
import java.util.Map;


/**
 * @author Teodor Danciu (teodord@users.sourceforge.net)
 */
public class SubreportApp extends AbstractSampleApp {


    /**
     *
     */
    public static void main(String[] args) {
        main(new SubreportApp(), args);
    }


    @Override
    public void test() throws JRException {
        fill();
        pdf();
        bmp();
        gif();
        jpeg();
        png();
        tiff();
        psd();
        jpeg2000();
        webp();
        emf();
        dicom();
        svg();
        wmf();
        html5Canvas();
    }

    /**
     *
     */
    public void fill() throws JRException {
        long start = System.currentTimeMillis();
        JasperReport subreport = (JasperReport) JRLoader.loadObjectFromFile("build/reports/ProductReport.jasper");

        //Preparing parameters
        Map<String, Object> parameters = new HashMap<String, Object>();
        parameters.put("ProductsSubreport", subreport);

        JasperFillManager.fillReportToFile("build/reports/MasterReport.jasper", parameters, getDemoHsqldbConnection());
        System.err.println("Filling time : " + (System.currentTimeMillis() - start));
    }

    /**
     *
     */
    public void print() throws JRException {
        long start = System.currentTimeMillis();
        JasperPrintManager.printReport("build/reports/MasterReport.jrprint", true);
        System.err.println("Printing time : " + (System.currentTimeMillis() - start));
    }

    public void html5Canvas() throws JRException {
        long start = System.currentTimeMillis();
        ASHtml5CanvasExporter exporter = new ASHtml5CanvasExporter();
        exporter.setExporterInput(new ASExportInputImpl("build/reports/MasterReport.jrprint"));
        exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/MasterReport.html"));
        exporter.exportReport();
        System.err.println("HTML5 canvas creation time : " + (System.currentTimeMillis() - start));
    }

    public void wmf() throws JRException {
        long start = System.currentTimeMillis();
        ASWmfExporter exporter = new ASWmfExporter();
        exporter.setExporterInput(new ASExportInputImpl("build/reports/MasterReport.jrprint"));
        exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/MasterReport.wmf"));
        exporter.exportReport();
        System.err.println("WMF creation time : " + (System.currentTimeMillis() - start));
    }

    public void svg() throws JRException {
        long start = System.currentTimeMillis();
        ASSvgExporter exporter = new ASSvgExporter();
        exporter.setExporterInput(new ASExportInputImpl("build/reports/MasterReport.jrprint"));
        exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/MasterReport.svg"));
        exporter.exportReport();
        System.err.println("SVG creation time : " + (System.currentTimeMillis() - start));
    }

    public void dicom() throws JRException {
        long start = System.currentTimeMillis();
        ASDicomExporter exporter = new ASDicomExporter();
        exporter.setExporterInput(new ASExportInputImpl("build/reports/MasterReport.jrprint"));
        exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/MasterReport.dcm"));
        exporter.exportReport();
        System.err.println("DICOM creation time : " + (System.currentTimeMillis() - start));
    }

    public void emf() throws JRException {
        long start = System.currentTimeMillis();
        ASEmfExporter exporter = new ASEmfExporter();
        exporter.setExporterInput(new ASExportInputImpl("build/reports/MasterReport.jrprint"));
        exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/MasterReport.emf"));
        exporter.exportReport();
        System.err.println("EMF creation time : " + (System.currentTimeMillis() - start));
    }

    public void webp() throws JRException {
        long start = System.currentTimeMillis();
        ASWebPExporter exporter = new ASWebPExporter();
        exporter.setExporterInput(new ASExportInputImpl("build/reports/MasterReport.jrprint"));
        exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/MasterReport.webp"));
        exporter.exportReport();
        System.err.println("WEBP creation time : " + (System.currentTimeMillis() - start));
    }

    public void jpeg2000() throws JRException {
        long start = System.currentTimeMillis();
        ASJpeg2000Exporter exporter = new ASJpeg2000Exporter();
        exporter.setExporterInput(new ASExportInputImpl("build/reports/MasterReport.jrprint"));
        exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/MasterReport.jp2"));
        exporter.exportReport();
        System.err.println("JPEG2000 creation time : " + (System.currentTimeMillis() - start));
    }

    public void psd() throws JRException {
        long start = System.currentTimeMillis();
        ASPsdExporter exporter = new ASPsdExporter();
        exporter.setExporterInput(new ASExportInputImpl("build/reports/MasterReport.jrprint"));
        exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/MasterReport.psd"));
        exporter.exportReport();
        System.err.println("PSD creation time : " + (System.currentTimeMillis() - start));
    }

    public void tiff() throws JRException {
        long start = System.currentTimeMillis();
        ASTiffExporter exporter = new ASTiffExporter();
        exporter.setExporterInput(new ASExportInputImpl("build/reports/MasterReport.jrprint"));
        exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/MasterReport.tiff"));
        exporter.exportReport();
        System.err.println("TIFF creation time : " + (System.currentTimeMillis() - start));
    }

    public void png() throws JRException {
        long start = System.currentTimeMillis();
        ASPngExporter exporter = new ASPngExporter();
        exporter.setExporterInput(new ASExportInputImpl("build/reports/MasterReport.jrprint"));
        exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/MasterReport.png"));
        exporter.exportReport();
        System.err.println("PNG creation time : " + (System.currentTimeMillis() - start));
    }

    public void jpeg() throws JRException {
        long start = System.currentTimeMillis();
        ASJpegExporter exporter = new ASJpegExporter();
        exporter.setExporterInput(new ASExportInputImpl("build/reports/MasterReport.jrprint"));
        exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/MasterReport.jpeg"));
        exporter.exportReport();
        System.err.println("JPEG creation time : " + (System.currentTimeMillis() - start));
    }

    public void gif() throws JRException {
        long start = System.currentTimeMillis();
        ASGifExporter exporter = new ASGifExporter();
        exporter.setExporterInput(new ASExportInputImpl("build/reports/MasterReport.jrprint"));
        exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/MasterReport.gif"));
        exporter.exportReport();
        System.err.println("GIF creation time : " + (System.currentTimeMillis() - start));
    }

    public void bmp() throws JRException {
        long start = System.currentTimeMillis();
        ASBmpExporter exporter = new ASBmpExporter();
        exporter.setExporterInput(new ASExportInputImpl("build/reports/MasterReport.jrprint"));
        exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/MasterReport.bmp"));
        exporter.exportReport();
        System.err.println("BMP creation time : " + (System.currentTimeMillis() - start));
    }


    /**
     *
     */
    public void pdf() throws JRException {
        long start = System.currentTimeMillis();
        ASPdfExporter exporter = new ASPdfExporter();
        exporter.setExporterInput(new ASExportInputImpl("build/reports/MasterReport.jrprint"));
        exporter.setExporterOutput(new ASExporterOutputImpl("build/reports/MasterReport.pdf"));
        exporter.exportReport();
        System.err.println("PDF creation time : " + (System.currentTimeMillis() - start));
    }
}
